import { Test, TestingModule } from '@nestjs/testing';
import { PersonsController } from './persons.controller';
import { PersonsService } from '../services/persons.service';
import { CreatePersonDto, Gender, OralEaseLevel } from '../dto/create-person.dto';
import { UpdatePersonDto } from '../dto/update-person.dto';
import { JwtAuthGuard } from '../../auth/guards/jwt-auth.guard';

describe('PersonsController', () => {
  let controller: PersonsController;
  let service: PersonsService;

  // Mock data
  const mockPerson = {
    id: 'person1',
    firstName: 'John',
    lastName: 'Doe',
    gender: Gender.MALE,
    technicalLevel: 3,
    hasTechnicalTraining: true,
    frenchSpeakingLevel: 4,
    oralEaseLevel: OralEaseLevel.COMFORTABLE,
    age: 30,
    projectId: 'project1',
    attributes: {},
    createdAt: new Date(),
    updatedAt: new Date(),
  };

  const mockPersonToGroup = {
    personId: 'person1',
    groupId: 'group1',
  };

  beforeEach(async () => {
    const module: TestingModule = await Test.createTestingModule({
      controllers: [PersonsController],
      providers: [
        {
          provide: PersonsService,
          useValue: {
            create: jest.fn().mockResolvedValue(mockPerson),
            findAll: jest.fn().mockResolvedValue([mockPerson]),
            findByProjectId: jest.fn().mockResolvedValue([mockPerson]),
            findById: jest.fn().mockResolvedValue(mockPerson),
            update: jest.fn().mockResolvedValue(mockPerson),
            remove: jest.fn().mockResolvedValue(mockPerson),
            findByProjectIdAndGroupId: jest.fn().mockResolvedValue([{ person: mockPerson }]),
            addToGroup: jest.fn().mockResolvedValue(mockPersonToGroup),
            removeFromGroup: jest.fn().mockResolvedValue(mockPersonToGroup),
          },
        },
      ],
    })
    .overrideGuard(JwtAuthGuard)
    .useValue({ canActivate: () => true })
    .compile();

    controller = module.get<PersonsController>(PersonsController);
    service = module.get<PersonsService>(PersonsService);
  });

  it('should be defined', () => {
    expect(controller).toBeDefined();
  });

  describe('create', () => {
    it('should create a new person', async () => {
      const createPersonDto: CreatePersonDto = {
        firstName: 'John',
        lastName: 'Doe',
        gender: Gender.MALE,
        technicalLevel: 3,
        hasTechnicalTraining: true,
        frenchSpeakingLevel: 4,
        oralEaseLevel: OralEaseLevel.COMFORTABLE,
        projectId: 'project1',
      };

      expect(await controller.create(createPersonDto)).toBe(mockPerson);
      expect(service.create).toHaveBeenCalledWith(createPersonDto);
    });
  });

  describe('findAll', () => {
    it('should return all persons when no projectId is provided', async () => {
      expect(await controller.findAll()).toEqual([mockPerson]);
      expect(service.findAll).toHaveBeenCalled();
    });

    it('should return persons filtered by projectId when projectId is provided', async () => {
      const projectId = 'project1';
      expect(await controller.findAll(projectId)).toEqual([mockPerson]);
      expect(service.findByProjectId).toHaveBeenCalledWith(projectId);
    });
  });

  describe('findOne', () => {
    it('should return a person by ID', async () => {
      const id = 'person1';
      expect(await controller.findOne(id)).toBe(mockPerson);
      expect(service.findById).toHaveBeenCalledWith(id);
    });
  });

  describe('update', () => {
    it('should update a person', async () => {
      const id = 'person1';
      const updatePersonDto: UpdatePersonDto = {
        firstName: 'Jane',
      };

      expect(await controller.update(id, updatePersonDto)).toBe(mockPerson);
      expect(service.update).toHaveBeenCalledWith(id, updatePersonDto);
    });
  });

  describe('remove', () => {
    it('should delete a person', async () => {
      const id = 'person1';
      expect(await controller.remove(id)).toBe(mockPerson);
      expect(service.remove).toHaveBeenCalledWith(id);
    });
  });

  describe('findByProjectIdAndGroupId', () => {
    it('should return persons by project ID and group ID', async () => {
      const projectId = 'project1';
      const groupId = 'group1';

      expect(await controller.findByProjectIdAndGroupId(projectId, groupId)).toEqual([{ person: mockPerson }]);
      expect(service.findByProjectIdAndGroupId).toHaveBeenCalledWith(projectId, groupId);
    });
  });

  describe('addToGroup', () => {
    it('should add a person to a group', async () => {
      const id = 'person1';
      const groupId = 'group1';

      expect(await controller.addToGroup(id, groupId)).toBe(mockPersonToGroup);
      expect(service.addToGroup).toHaveBeenCalledWith(id, groupId);
    });
  });

  describe('removeFromGroup', () => {
    it('should remove a person from a group', async () => {
      const id = 'person1';
      const groupId = 'group1';

      expect(await controller.removeFromGroup(id, groupId)).toBe(mockPersonToGroup);
      expect(service.removeFromGroup).toHaveBeenCalledWith(id, groupId);
    });
  });
});